@@ -78,7 +78,7 @@ REDIRECT_URI_PARANOID = "http://not.a.realhost/"
 def is_slack_url(url):
     return ".slack.com/" in url or "slack-edge.com/" in url or "slack-files.com/" in url
 
-def json_dump(obj, fp)
+def json_dump(obj, fp):
     # Indentation and sorting keys is friendlier for git diffs
     json.dump(obj, fp, ensure_ascii=False, indent=JSON_INDENT, sort_keys=True)
 
